from setuptools import setup

setup(name='Pranay_Udacity_distributions',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['Pranay_Udacity_distributions'],
      author="Pranay Barkataki",
      author_email="pranay.barkataki@gmail.com",
      zip_safe=False)
